@@ -160,7 +160,9 @@ class Collection(BaseModel):
        
     def add(self, vector_id, vector_data):
         session.post("/collections/%d/vectors/%d" % (self.id, vector_id), json={'vector': list(vector_data)})
-        
+        if not self.dimension:
+            self.dimension = len(vector_data)  # record dimension
+            
     def create_index(self,
                      tag='latest',
                      target_library=IndexLibraries.hnswlib,
@@ -200,7 +202,14 @@ class Collection(BaseModel):
     def get_all_index(self):
         return self.get_index(None)
 
-
+    def _update(self):
+        resp = session.get(f"/collections/{self.id}")
+        self.__dict__.update(resp.json())
+        
+    def __getattribute__(self, attr):
+        if attr in ['count', 'updated_at']:
+            self._update()
+        return object.__getattribute__(self, attr)        
 
 
 def create_collection(name):
